==> pandoc-crossref-0.3.4.0-68-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.4.0
id: pandoc-crossref-0.3.4.0-CS1Cl2Lcn0Y8b8vGWoBvxj
key: pandoc-crossref-0.3.4.0-CS1Cl2Lcn0Y8b8vGWoBvxj
license: GPL-2.0-only
maintainer: root@livid.pp.ru
author: Nikolay Yakimov
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
abi: 11ade5b11433b0d65bac053f0612418d
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
import-dirs: /usr/lib/ghc-8.6.4/site-local/pandoc-crossref-0.3.4.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/pandoc-crossref-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.4.0-CS1Cl2Lcn0Y8b8vGWoBvxj
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-accessor-0.2.2.8-AYq93Bw1A2YHILUYropyUn
    data-accessor-template-0.2.1.16-Iitk7dZ2vVF1n1UiWEY5LJ
    data-accessor-transformers-0.2.1.7-5wbZaRH8II89QeXVhYgfQ4
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4 directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pandoc-2.7.1-HkBJoICh1AjC7csEVFpCni
    pandoc-types-1.17.5.4-Dv3jPr775yC6XC1hEZTVYr
    roman-numerals-0.5.1.5-3za2AazuRwa402pxXteKHr
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.4.0-72-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.4.0
id: pandoc-crossref-0.3.4.0-9wBzwkFz59gGIpdBkCvavP
key: pandoc-crossref-0.3.4.0-9wBzwkFz59gGIpdBkCvavP
license: GPL-2.0-only
maintainer: root@livid.pp.ru
author: Nikolay Yakimov
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
abi: 2f271966323a34c3bf97ac8036d03f0c
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
import-dirs: /usr/lib/ghc-8.6.4/site-local/pandoc-crossref-0.3.4.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/pandoc-crossref-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.4.0-9wBzwkFz59gGIpdBkCvavP
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-accessor-0.2.2.8-AYq93Bw1A2YHILUYropyUn
    data-accessor-template-0.2.1.16-Iitk7dZ2vVF1n1UiWEY5LJ
    data-accessor-transformers-0.2.1.7-5wbZaRH8II89QeXVhYgfQ4
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4 directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pandoc-2.7.2-EDRNWgb9XXK6kGTlmf4mQw
    pandoc-types-1.17.5.4-Dv3jPr775yC6XC1hEZTVYr
    roman-numerals-0.5.1.5-3za2AazuRwa402pxXteKHr
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
